@@ -15,8 +15,7 @@ __all__ = ["QueryScore", "normalize_query", "update_score_by_url"]
 
 
 def update_score_by_url(pkg: model.Package, ref: Optional[str] = None) -> bool:
-    """Make given package more relevant for the current search query.
-    """
+    """Make given package more relevant for the current search query."""
     if tk.request:
         ref = ref or tk.request.referrer
 
