@@ -72,7 +72,8 @@ def spellcheck_did_you_mean(
         new_q = " ".join(
             [spellcheck.suggestions[w][0] for w in terms if w in spellcheck.suggestions]
         )
-        collations.append(new_q)
+        if new_q:
+            collations.append(new_q)
 
     return collations
 
@@ -107,14 +108,14 @@ class Collation:
             return self.hits == other
         return self.hits == other.hits and self.query == other.query
 
-    def __gt__(self, other):
+    def __lt__(self, other):
         if isinstance(other, int):
-            return self.hits > other
+            return self.hits < other
 
         if self.hits == other.hits:
-            return self.query > other.query
+            return self.query < other.query
 
-        return self.hits > other.hits
+        return self.hits < other.hits
 
     def __str__(self):
         return self.query
@@ -137,4 +138,4 @@ class SpellcheckResult:
         )
 
     def best_collations(self, n: Optional[int] = None) -> list[Collation]:
-        return sorted(self.collations)[:n]
+        return sorted(self.collations, reverse=True)[:n]
